@@ -19,12 +19,9 @@
 
 from __future__ import with_statement
 
-import locale
-import os
 import re
 from .basecase import BaseTestCase, cqlsh
 from .cassconnect import testrun_cqlsh
-from .run_cqlsh import TimeoutError
 import unittest
 import sys
 
@@ -45,11 +42,7 @@ completion_separation_re = re.compile(r'\s+')
 class CqlshCompletionCase(BaseTestCase):
 
     def setUp(self):
-        env = os.environ.copy()
-        env['COLUMNS'] = '100000'
-        if (locale.getpreferredencoding() != 'UTF-8'):
-             env['LC_CTYPE'] = 'en_US.utf8'
-        self.cqlsh_runner = testrun_cqlsh(cqlver=None, env=env)
+        self.cqlsh_runner = testrun_cqlsh(cqlver=cqlsh.DEFAULT_CQLVER, env={'COLUMNS': '100000'})
         self.cqlsh = self.cqlsh_runner.__enter__()
 
     def tearDown(self):
@@ -95,7 +88,7 @@ class CqlshCompletionCase(BaseTestCase):
 
         if split_completed_lines:
             completed_lines = map(set, (completion_separation_re.split(line.strip())
-                                  for line in choice_lines))
+                               for line in choice_lines))
 
             if not completed_lines:
                 return set()
@@ -120,7 +113,7 @@ class CqlshCompletionCase(BaseTestCase):
         match the items in 'choices' (order is not important, but case is).
         """
         completed = self._get_completions(inputstring,
-                                          split_completed_lines=split_completed_lines)
+                                         split_completed_lines=split_completed_lines)
 
         if immediate:
             msg = 'cqlsh completed %r, but we expected %r' % (completed, immediate)
@@ -139,14 +132,8 @@ class CqlshCompletionCase(BaseTestCase):
                                        other_choices_ok=other_choices_ok,
                                        split_completed_lines=split_completed_lines)
         finally:
-            try:
-                self.cqlsh.send(CTRL_C)  # cancel any current line
-                self.cqlsh.read_to_next_prompt(timeout=1.0)
-            except TimeoutError:
-                # retry once
-                self.cqlsh.send(CTRL_C)
-                self.cqlsh.read_to_next_prompt(timeout=10.0)
-
+            self.cqlsh.send(CTRL_C)  # cancel any current line
+            self.cqlsh.read_to_next_prompt()
 
     def strategies(self):
         return self.module.CqlRuleSet.replication_strategies
@@ -419,7 +406,7 @@ class TestCqlshCompletion(CqlshCompletionCase):
                                      'utf8_with_special_chars',
                                      'system_traces.', 'songs',
                                      'system_auth.', 'system_distributed.',
-                                     'system_schema.', 'system_traces.',
+                                     'system_schema.','system_traces.',
                                      '"' + self.cqlsh.keyspace + '".'],
                             other_choices_ok=True)
         self.trycompletions('DELETE FROM twenty_rows_composite_table ',
@@ -495,34 +482,34 @@ class TestCqlshCompletion(CqlshCompletionCase):
                             choices=self.strategies())
         # ttl is an "unreserved keyword". should work
         self.trycompletions("create keySPACE ttl with replication ="
-                            "{ 'class' : 'SimpleStrategy'", ", 'replication_factor': ")
+                               "{ 'class' : 'SimpleStrategy'", ", 'replication_factor': ")
         self.trycompletions("create   keyspace ttl with replication ="
-                            "{'class':'SimpleStrategy',", " 'replication_factor': ")
+                               "{'class':'SimpleStrategy',", " 'replication_factor': ")
         self.trycompletions("create keyspace \"ttl\" with replication ="
-                            "{'class': 'SimpleStrategy', ", "'replication_factor': ")
+                               "{'class': 'SimpleStrategy', ", "'replication_factor': ")
         self.trycompletions("create keyspace \"ttl\" with replication ="
-                            "{'class': 'SimpleStrategy', 'repl", "ication_factor'")
+                               "{'class': 'SimpleStrategy', 'repl", "ication_factor'")
         self.trycompletions("create keyspace foo with replication ="
-                            "{'class': 'SimpleStrategy', 'replication_factor': ", '',
+                               "{'class': 'SimpleStrategy', 'replication_factor': ", '',
                             choices=('<term>',))
         self.trycompletions("create keyspace foo with replication ="
-                            "{'class': 'SimpleStrategy', 'replication_factor': 1", '',
+                               "{'class': 'SimpleStrategy', 'replication_factor': 1", '',
                             choices=('<term>',))
         self.trycompletions("create keyspace foo with replication ="
-                            "{'class': 'SimpleStrategy', 'replication_factor': 1 ", '}')
+                               "{'class': 'SimpleStrategy', 'replication_factor': 1 ", '}')
         self.trycompletions("create keyspace foo with replication ="
-                            "{'class': 'SimpleStrategy', 'replication_factor': 1, ",
+                               "{'class': 'SimpleStrategy', 'replication_factor': 1, ",
                             '', choices=())
         self.trycompletions("create keyspace foo with replication ="
-                            "{'class': 'SimpleStrategy', 'replication_factor': 1} ",
+                               "{'class': 'SimpleStrategy', 'replication_factor': 1} ",
                             '', choices=('AND', ';'))
         self.trycompletions("create keyspace foo with replication ="
-                            "{'class': 'NetworkTopologyStrategy', ", '',
+                               "{'class': 'NetworkTopologyStrategy', ", '',
                             choices=('<dc_name>',))
         self.trycompletions("create keyspace \"PB and J\" with replication={"
-                            "'class': 'NetworkTopologyStrategy'", ', ')
+                               "'class': 'NetworkTopologyStrategy'", ', ')
         self.trycompletions("create keyspace PBJ with replication={"
-                            "'class': 'NetworkTopologyStrategy'} and ",
+                               "'class': 'NetworkTopologyStrategy'} and ",
                             "durable_writes = '")
 
     def test_complete_in_string_literals(self):
@@ -630,8 +617,7 @@ class TestCqlshCompletion(CqlshCompletionCase):
                             + "{'class': '",
                             choices=['SizeTieredCompactionStrategy',
                                      'LeveledCompactionStrategy',
-                                     'DateTieredCompactionStrategy',
-                                     'TimeWindowCompactionStrategy'])
+                                     'DateTieredCompactionStrategy'])
         self.trycompletions(prefix + " new_table (col_a int PRIMARY KEY) WITH compaction = "
                             + "{'class': 'S",
                             immediate="izeTieredCompactionStrategy'")
@@ -670,147 +656,21 @@ class TestCqlshCompletion(CqlshCompletionCase):
         self.trycompletions(prefix + " new_table (col_a int PRIMARY KEY) WITH compaction = "
                             + "{'class': 'DateTieredCompactionStrategy', '",
                             choices=['base_time_seconds', 'max_sstable_age_days',
-                                     'timestamp_resolution', 'min_threshold', 'class', 'max_threshold',
-                                     'tombstone_compaction_interval', 'tombstone_threshold',
-                                     'enabled', 'unchecked_tombstone_compaction',
-                                     'max_window_size_seconds', 'only_purge_repaired_tombstones'])
-        self.trycompletions(prefix + " new_table (col_a int PRIMARY KEY) WITH compaction = "
-                            + "{'class': 'TimeWindowCompactionStrategy', '",
-                            choices=['compaction_window_unit', 'compaction_window_size',
-                                     'timestamp_resolution', 'min_threshold', 'class', 'max_threshold',
-                                     'tombstone_compaction_interval', 'tombstone_threshold',
-                                     'enabled', 'unchecked_tombstone_compaction',
-                                     'only_purge_repaired_tombstones'])
-
+                                    'timestamp_resolution', 'min_threshold', 'class', 'max_threshold',
+                                    'tombstone_compaction_interval', 'tombstone_threshold',
+                                    'enabled', 'unchecked_tombstone_compaction',
+                                    'max_window_size_seconds', 'only_purge_repaired_tombstones'])
 
     def test_complete_in_create_columnfamily(self):
         self.trycompletions('CREATE C', choices=['COLUMNFAMILY', 'CUSTOM'])
         self.trycompletions('CREATE CO', immediate='LUMNFAMILY ')
         self.create_columnfamily_table_template('COLUMNFAMILY')
 
-    def test_complete_in_create_materializedview(self):
-        self.trycompletions('CREATE MAT', immediate='ERIALIZED VIEW ')
-        self.trycompletions('CREATE MATERIALIZED VIEW AS ', choices=['AS', 'SELECT'])
-        self.trycompletions('CREATE MATERIALIZED VIEW AS SELECT * ', immediate='FROM ')
-        self.trycompletions('CREATE MATERIALIZED VIEW AS SELECT * FROM system.peers ', immediate = 'WHERE ')
-        self.trycompletions('CREATE MATERIALIZED VIEW AS SELECT * FROM system.peers WHERE host_id ', immediate='IS NOT NULL ' )
-        self.trycompletions('CREATE MATERIALIZED VIEW AS SELECT * FROM system.peers WHERE host_id IS NOT NULL PR', immediate='IMARY KEY ( ')
-        self.trycompletions('CREATE MATERIALIZED VIEW AS SELECT * FROM system.peers WHERE host_id IS NOT NULL PRIMARY KEY (host_id) ', choices=[';','WITH'])
-        self.trycompletions('CREATE MATERIALIZED VIEW AS SELECT * FROM system.peers WHERE host_id IS NOT NULL PRIMARY KEY (a, b) ', choices=[';','WITH'])
-        self.trycompletions('CREATE MATERIALIZED VIEW AS SELECT * FROM system.peers WHERE host_id IS NOT NULL PRIMARY KEY ((a,b), c) ', choices=[';','WITH'])
-
     def test_complete_in_create_table(self):
         self.trycompletions('CREATE T', choices=['TRIGGER', 'TABLE', 'TYPE'])
         self.trycompletions('CREATE TA', immediate='BLE ')
         self.create_columnfamily_table_template('TABLE')
 
-    def test_complete_in_describe(self):
-        """
-        Tests for Cassandra-10733
-        """
-        self.trycompletions('DES', immediate='C')
-        # quoted_keyspace = '"' + self.cqlsh.keyspace + '"'
-        self.trycompletions('DESCR', immediate='IBE ')
-        self.trycompletions('DESC TABLE ',
-                            choices=['twenty_rows_table',
-                                     'ascii_with_special_chars', 'users',
-                                     'has_all_types', 'system.',
-                                     'empty_composite_table', 'empty_table',
-                                     'system_auth.', 'undefined_values_table',
-                                     'dynamic_columns',
-                                     'twenty_rows_composite_table',
-                                     'utf8_with_special_chars',
-                                     'system_traces.', 'songs',
-                                     'system_distributed.',
-                                     '"' + self.cqlsh.keyspace + '".'],
-                            other_choices_ok=True)
-
-        self.trycompletions('DESC TYPE ',
-                            choices=['system.',
-                                     'system_auth.',
-                                     'system_traces.',
-                                     'system_distributed.',
-                                     'address',
-                                     'phone_number',
-                                     'band_info_type',
-                                     'tags'],
-                            other_choices_ok=True)
-
-        self.trycompletions('DESC FUNCTION ',
-                            choices=['system.',
-                                     'system_auth.',
-                                     'system_traces.',
-                                     'system_distributed.',
-                                     'fbestband',
-                                     'fbestsong',
-                                     'fmax',
-                                     'fmin',
-                                     '"' + self.cqlsh.keyspace + '".'],
-                            other_choices_ok=True)
-
-        self.trycompletions('DESC AGGREGATE ',
-                            choices=['system.',
-                                     'system_auth.',
-                                     'system_traces.',
-                                     'system_distributed.',
-                                     'aggmin',
-                                     'aggmax',
-                                     '"' + self.cqlsh.keyspace + '".'],
-                            other_choices_ok=True)
-
-        # Unfortunately these commented tests will not work. This is due to the keyspace name containing quotes;
-        # cqlsh auto-completes a DESC differently when the keyspace contains quotes. I'll leave the
-        # test here though in case we ever change this script to test using keyspace names without
-        # quotes
-
-        # self.trycompletions('DESC TABLE ' + '"' + self.cqlsh.keyspace + '"', immediate='.')
-
-        self.trycompletions('DESC TABLE ' + '"' + self.cqlsh.keyspace + '".',
-                            choices=['twenty_rows_table',
-                                     'ascii_with_special_chars',
-                                     'users',
-                                     'has_all_types',
-                                     'empty_composite_table',
-                                     'empty_table',
-                                     'undefined_values_table',
-                                     'dynamic_columns',
-                                     'twenty_rows_composite_table',
-                                     'utf8_with_special_chars',
-                                     'songs'],
-                            other_choices_ok=True)
-
-        # See comment above for DESC TABLE
-        # self.trycompletions('DESC TYPE ' + '"' + self.cqlsh.keyspace + '"', immediate='.')
-
-        self.trycompletions('DESC TYPE ' + '"' + self.cqlsh.keyspace + '".',
-                            choices=['address',
-                                     'phone_number',
-                                     'band_info_type',
-                                     'tags'],
-                            other_choices_ok=True)
-
-        # See comment above for DESC TABLE
-        # self.trycompletions('DESC FUNCTION ' + '"' + self.cqlsh.keyspace + '"', immediate='.f')
-
-        self.trycompletions('DESC FUNCTION ' + '"' + self.cqlsh.keyspace + '".', immediate='f')
-
-        self.trycompletions('DESC FUNCTION ' + '"' + self.cqlsh.keyspace + '".f',
-                            choices=['fbestband',
-                                     'fbestsong',
-                                     'fmax',
-                                     'fmin'],
-                            other_choices_ok=True)
-
-        # See comment above for DESC TABLE
-        # self.trycompletions('DESC AGGREGATE ' + '"' + self.cqlsh.keyspace + '"', immediate='.aggm')
-
-        self.trycompletions('DESC AGGREGATE ' + '"' + self.cqlsh.keyspace + '".', immediate='aggm')
-
-        self.trycompletions('DESC AGGREGATE ' + '"' + self.cqlsh.keyspace + '".aggm',
-                            choices=['aggmin',
-                                     'aggmax'],
-                            other_choices_ok=True)
-
     def test_complete_in_drop_columnfamily(self):
         pass
 
